package
Version:
v0.0.0-...-b311a88
Opens a new window with list of versions in this module.
Published: Mar 27, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Commit struct {
Sha string `json:"sha"`
Message string `json:"message"`
Author string `json:"author"`
PushedAt *time.Time `json:"pushed_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.